[PATCH 09/10] qla4xxx: rename del_from_active_array

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Doug Maxey <dwm@xxxxxxxxxxx>

- add the driver prefix

Signed-off-by: Doug Maxey <dwm@xxxxxxxxxxx>
---

 drivers/scsi/qla4xxx/ql4_glbl.h |    2 +-
 drivers/scsi/qla4xxx/ql4_isr.c  |   14 +++++++-------
 drivers/scsi/qla4xxx/ql4_os.c   |    6 +++---
 3 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/drivers/scsi/qla4xxx/ql4_glbl.h b/drivers/scsi/qla4xxx/ql4_glbl.h
index 6419339..09d0313 100644
--- a/drivers/scsi/qla4xxx/ql4_glbl.h
+++ b/drivers/scsi/qla4xxx/ql4_glbl.h
@@ -66,7 +66,7 @@ void qla4xxx_interrupt_service_routine(s
 				       uint32_t intr_status);
 int qla4xxx_init_rings(struct scsi_qla_host * ha);
 void qla4xxx_dump_buffer(void *b, uint32_t size);
-struct srb * del_from_active_array(struct scsi_qla_host *ha, uint32_t index);
+struct srb * qla4xxx_del_from_active_array(struct scsi_qla_host *ha, uint32_t index);
 void qla4xxx_srb_compl(struct scsi_qla_host *ha, struct srb *srb);
 int qla4xxx_reinitialize_ddb_list(struct scsi_qla_host * ha);
 int qla4xxx_process_ddb_changed(struct scsi_qla_host * ha,
diff --git a/drivers/scsi/qla4xxx/ql4_isr.c b/drivers/scsi/qla4xxx/ql4_isr.c
index bff2b72..4b23db0 100644
--- a/drivers/scsi/qla4xxx/ql4_isr.c
+++ b/drivers/scsi/qla4xxx/ql4_isr.c
@@ -17,7 +17,7 @@ static void qla4xxx_process_completed_re
 {
 	struct srb *srb;
 
-	srb = del_from_active_array(ha, index);
+	srb = qla4xxx_del_from_active_array(ha, index);
 	if (srb) {
 		/* Save ISP completion status */
 		srb->cmd->result = DID_OK << 16;
@@ -52,7 +52,7 @@ static void qla4xxx_status_entry(struct 
 		return;
 	}
 
-	srb = del_from_active_array(ha, le32_to_cpu(sts_entry->handle));
+	srb = qla4xxx_del_from_active_array(ha, le32_to_cpu(sts_entry->handle));
 	if (!srb) {
 		/* FIXMEdg: Don't we need to reset ISP in this case??? */
 		DEBUG2(printk(KERN_WARNING "scsi%ld: %s: Status Entry invalid "
@@ -354,9 +354,9 @@ static void qla4xxx_process_response_que
 			 * accepted by ISP.  Queue command for
 			 * later */
 
-			srb = del_from_active_array(ha,
-						    le32_to_cpu(sts_entry->
-								handle));
+			srb = qla4xxx_del_from_active_array(ha,
+							    le32_to_cpu(sts_entry->
+									handle));
 			if (srb == NULL)
 				goto exit_prq_invalid_handle;
 
@@ -588,7 +588,7 @@ static void qla4xxx_isr_decode_mailbox(s
  * qla4xxx_interrupt_service_routine - isr
  * @ha: pointer to host adapter structure.
  *
- * This is the main interrupt service routine.	
+ * This is the main interrupt service routine.
  * hardware_lock locked upon entry. runs in interrupt context.
  **/
 void qla4xxx_interrupt_service_routine(struct scsi_qla_host * ha,
@@ -713,7 +713,7 @@ irqreturn_t qla4xxx_intr_handler(int irq
  * @ha: pointer to host adapter structure.
  * @process_aen: type of AENs to process
  *
- * Processes specific types of Asynchronous Events generated by firmware. 
+ * Processes specific types of Asynchronous Events generated by firmware.
  * The type of AENs to process is specified by process_aen and can be
  *	PROCESS_ALL_AENS	 0
  *	FLUSH_DDB_CHANGED_AENS	 1
diff --git a/drivers/scsi/qla4xxx/ql4_os.c b/drivers/scsi/qla4xxx/ql4_os.c
index 7c48e54..f39eb5c 100644
--- a/drivers/scsi/qla4xxx/ql4_os.c
+++ b/drivers/scsi/qla4xxx/ql4_os.c
@@ -858,7 +858,7 @@ static void qla4xxx_flush_active_srbs(st
 	spin_lock_irqsave(&ha->hardware_lock, flags);
 	for (i = 1; i < MAX_SRBS; i++) {
 		if ((srb = ha->active_srb_array[i]) != NULL) {
-			del_from_active_array(ha, i);
+			qla4xxx_del_from_active_array(ha, i);
 			srb->cmd->result = DID_RESET << 16;
 			qla4xxx_srb_compl(ha, srb);
 		}
@@ -1430,13 +1430,13 @@ static int qla4xxx_slave_configure(struc
 }
 
 /**
  * del_from_active_array - returns an active srb
  * @ha: Pointer to host adapter structure.
  * @index: index into to the active_array
  *
  * This routine removes and returns the srb at the specified index
  **/
-struct srb * del_from_active_array(struct scsi_qla_host *ha, uint32_t index)
+struct srb * qla4xxx_del_from_active_array(struct scsi_qla_host *ha, uint32_t index)
 {
 	struct srb *srb = NULL;
 
-
@@ -1430,13 +1430,13 @@ static int qla4xxx_slave_configure(struc
 
 /**
- * del_from_active_array - returns an active srb
+ * qla4xxx_del_from_active_array - returns an active srb
  * @ha: Pointer to host adapter structure.
  * @index: index into to the active_array
: send the line "unsubscribe linux-scsi" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Index of Archives]     [SCSI Target Devel]     [Linux SCSI Target Infrastructure]     [Kernel Newbies]     [IDE]     [Security]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux ATA RAID]     [Linux IIO]     [Samba]     [Device Mapper]
  Powered by Linux